=======
History
=======

0.3.0 (2017-04-04)
------------------

* Fix health report
* Highlight "warning level" percentages in health
* Fix quoting to allow remote glob expansion


0.2.0 (2017-04-02)
------------------

* Refactor into object for coding w/ Kubey.
* Add initial tests.
* Add pass-thru calling.


0.1.0 (2017-03-18)
------------------

* First release on PyPI.
